==> eksctl-0.118.0.tar.gz: eksctl-0.118.0/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a bug report to help us improve eksctl
title: '[Bug] '
labels: kind/bug
assignees: ''

---

<!--
Thank you for opening this bug report! You are helping make eksctl a better project :)
In order to help us process this issue faster, please provide as much detail as possible.

When providing command examples, error output or code samples, please use code blocks.
For verbose output, for example logs, please either create a gist or use html details tags.
-->

<!--
Before you start writing:
1. Please search through existing issues to see whether your problem has already been reported.
2. Download the latest version of eksctl to see whether the problem has already been fixed.

For more information on how to open a bug report in eksctl, please refer to our issue submission guide.
https://github.com/weaveworks/eksctl/blob/main/CONTRIBUTING.md#opening-issues
-->

### What were you trying to accomplish?
<!-- Information about the command you ran and what you expected to happen. -->

### What happened?
<!-- A description of actual behavior (with error messages). -->

### How to reproduce it?
<!--
Include ALL the steps to reproduce the bug.

If using a config file, include it here, removing any sensitive information!
-->


**Logs**
<!--
Include the output of the command line when running eksctl. If possible, eksctl should be run with debug logs. For example:
`eksctl get clusters -v 4`
Make sure you redact any sensitive information before posting.
If the output is long, please consider a Gist, or an html details tag.
-->

**Anything else we need to know?**
<!--
What OS are you using?
Are you using a downloaded binary or did you compile eksctl?
What type of AWS credentials are you using (i.e. default/named profile, MFA)? - please don't include actual credentials though!
-->

**Versions**
<!--
Please paste in the output of this command:
-->
```
$ eksctl info
```

==> eksctl-0.168.0.tar.gz: eksctl-0.168.0/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a bug report to help us improve eksctl
title: '[Bug] '
labels: kind/bug
assignees: ''

---

<!--
Thank you for opening this bug report! You are helping make eksctl a better project :)
In order to help us process this issue faster, please provide as much detail as possible.

When providing command examples, error output or code samples, please use code blocks.
For verbose output, for example logs, please either create a gist or use html details tags.
-->

<!--
Before you start writing:
1. Please search through existing issues to see whether your problem has already been reported.
2. Download the latest version of eksctl to see whether the problem has already been fixed.

For more information on how to open a bug report in eksctl, please refer to our issue submission guide.
https://github.com/eksctl-io/eksctl/blob/main/CONTRIBUTING.md#opening-issues
-->

### What were you trying to accomplish?
<!-- Information about the command you ran and what you expected to happen. -->

### What happened?
<!-- A description of actual behavior (with error messages). -->

### How to reproduce it?
<!--
Include ALL the steps to reproduce the bug.

If using a config file, include it here, removing any sensitive information!
-->


**Logs**
<!--
Include the output of the command line when running eksctl. If possible, eksctl should be run with debug logs. For example:
`eksctl get clusters -v 4`
Make sure you redact any sensitive information before posting.
If the output is long, please consider a Gist, or an html details tag.
-->

**Anything else we need to know?**
<!--
What OS are you using?
Are you using a downloaded binary or did you compile eksctl?
What type of AWS credentials are you using (i.e. default/named profile, MFA)? - please don't include actual credentials though!
-->

**Versions**
<!--
Please paste in the output of this command:
-->
```
$ eksctl info
```
